@@ -56,7 +56,9 @@ pub const U16_SMALL_W: u16 = 119;
 pub const U16_SMALL_X: u16 = 120;
 pub const U16_SMALL_Y: u16 = 121;
 pub const U16_SMALL_Z: u16 = 122;
+pub const U16_LEFT_CURLY_BRACE: u16 = 123;
 pub const U16_VERTICAL_BAR: u16 = 124;
+pub const U16_RIGHT_CURLY_BRACE: u16 = 125;
 pub const U16_TILDE: u16 = 126;
 
 
