@@ -12,12 +12,21 @@ pub fn from_file(input: &str) -> String {
     let mut st = String::new();
 
     f.read_to_string(&mut st).unwrap();
-    crate::markdown::render(&st).unwrap()
+    markdown::render(&st).unwrap()
 }
 
 
 pub fn render(input: String) -> String {
-    crate::markdown::render(&input).unwrap()
+    markdown::render(&input).unwrap()
+}
+
+
+pub fn get_svg_icon(name: &str, size: usize, color: (u8, u8, u8)) -> Option<String> {
+
+    match markdown::icon::get_icon(&crate::utils::into_v16(name), size, Some(color)) {
+        None => None,
+        Some(v) => Some(String::from_utf16_lossy(&v))
+    }
 }
 
 
