@@ -1,4 +1,4 @@
-use crate::markdown::escape::prevent_backslash_escape;
+use crate::markdown::escape::undo_backslash_escape;
 use crate::markdown::line::{Line, LineType};
 use crate::markdown::syntax_highlighter::SyntaxHighlighter;
 use crate::utils::{drop_while, get_parenthesis_end_index};
@@ -145,7 +145,7 @@ fn construct_code_fence(mut lines: Vec<Line>, mut options: CodeFenceOption, synt
     // removes trailing `\n`
     result.content = content[0..content.len() - 1].concat();
 
-    result.content = prevent_backslash_escape(&result.content);
+    result.content = undo_backslash_escape(&result.content);
 
     result
 }
