@@ -1,4 +1,5 @@
 use crate::consts::*;
+use crate::utils::into_v16;
 
 
 /*
@@ -109,46 +110,92 @@ pub fn is_escaped(content: &Vec<u16>, index: usize) -> Option<(u16, usize)> {
 
 pub fn escape_backslashes(content: &Vec<u16>) -> Vec<u16> {
 
+    let mut index = 0;
     let mut result = Vec::with_capacity(content.len());
-    let mut is_escaped = false;
 
-    for c in content.iter() {
+    while index < content.len() {
 
-        if is_escaped {
-            is_escaped = false;
-            result.push(*c);
-            continue;
-        }
+        if content[index] == U16_BACKSLASH {
+            result.push(BACKSLASH_ESCAPE_MARKER);
+
+            if index + 1 >= content.len() {
+                return result;
+            }
+
+            else if content[index + 1] != U16_NEWLINE {
+                result.push(u16::MAX - content[index + 1]);
+                index += 1;
+            }
 
-        if *c == U16_BACKSLASH {
-            is_escaped = true;
         }
 
         else {
-            result.push(*c);
+            result.push(content[index]);
         }
 
+        index += 1;
     }
 
     result
 }
 
 
-pub fn prevent_backslash_escape(content: &Vec<u16>) -> Vec<u16> {
+pub fn undo_backslash_escape(content: &Vec<u16>) -> Vec<u16> {
 
-    let mut result = Vec::with_capacity(content.len() + content.len() / 10);
+    let mut index = 0;
+    let mut result = Vec::with_capacity(content.len());
 
-    for c in content.iter() {
+    while index < content.len() {
 
-        if *c == U16_BACKSLASH {
-            result.push(U16_BACKSLASH);
+        if content[index] == BACKSLASH_ESCAPE_MARKER {
             result.push(U16_BACKSLASH);
+
+            if index + 1 == content.len() {
+                return result;
+            }
+
+            else {
+                result.push(u16::MAX - content[index + 1]);
+                index += 1;
+            }
+
         }
 
         else {
-            result.push(*c);
+            result.push(content[index]);
         }
 
+        index += 1;
+    }
+
+    result
+}
+
+
+pub fn render_backslash_escape(content: &Vec<u16>) -> Vec<u16> {
+
+    let mut result = Vec::with_capacity(content.len() + content.len() / 4);
+    let mut index = 0;
+
+    while index < content.len() {
+
+        if content[index] == BACKSLASH_ESCAPE_MARKER {
+            result.push(U16_AMPERSAND);
+            result.push(U16_SHARP);
+
+            for num in into_v16(&(u16::MAX - content[index + 1]).to_string()) {
+                result.push(num);
+            }
+
+            result.push(U16_SEMI_COLON);
+            index += 1;
+        }
+
+        else {
+            result.push(content[index]);
+        }
+
+        index += 1;
     }
 
     result
