@@ -1,5 +1,5 @@
 use crate::markdown::line::{Line, LineType};
-use crate::markdown::inline::render_inline;
+use crate::markdown::inline::{render_inline, render_inline_raw};
 use crate::consts::*;
 use crate::utils::into_v16;
 
@@ -92,7 +92,7 @@ fn construct_table(lines: Vec<Line>) -> Line {
 
     for th in table_head.iter() {
         result.push(into_v16("<th>"));
-        result.push(th.clone());
+        result.push(render_inline_raw(th));
         result.push(into_v16("</th>"));
     }
 
@@ -108,7 +108,7 @@ fn construct_table(lines: Vec<Line>) -> Line {
             }
 
             result.push(alignments[ind].render());
-            result.push(td.clone());
+            result.push(render_inline_raw(td));
             result.push(into_v16("</td>"));
         }
 
